package com.usky.sas.service;

import com.usky.common.core.bean.CommonPage;
import com.usky.sas.service.vo.EventDetailResponse;
import com.usky.sas.service.vo.IntelligentEventItem;
import com.usky.sas.service.vo.IntelligentEventPageRequest;

public interface SasIntelligentService {

    CommonPage<IntelligentEventItem> queryEvents(IntelligentEventPageRequest request);

    CommonPage<IntelligentEventItem> querySnap(IntelligentEventPageRequest request);

    CommonPage<IntelligentEventItem> queryAlarm(IntelligentEventPageRequest request);

    CommonPage<IntelligentEventItem> queryEntrance(IntelligentEventPageRequest request);

    CommonPage<IntelligentEventItem> queryParking(IntelligentEventPageRequest request);

    CommonPage<IntelligentEventItem> queryPatrol(IntelligentEventPageRequest request);

    CommonPage<IntelligentEventItem> queryUsb(IntelligentEventPageRequest request);

    CommonPage<IntelligentEventItem> queryPerception(IntelligentEventPageRequest request);

    CommonPage<IntelligentEventItem> queryAcquisition(IntelligentEventPageRequest request);

    CommonPage<IntelligentEventItem> queryCollection(IntelligentEventPageRequest request);

    CommonPage<IntelligentEventItem> queryRoadblock(IntelligentEventPageRequest request);

}

